%define ver	2020.04
%define gitdate	20200713
%define githash	ca6e787
%define rel	3

%define use_system_waf 0
%{?_with_system_waf: %global use_system_waf 1}
%{?_without_system_waf: %global use_system_waf 0}

%define glesv2name              mesaglesv2
%define glesv2major		2
%define libglesv2name		%mklibname %{glesv2name}_ %{glesv2major}

Name:		glmark2
Version:	%{ver}
Release:	%mkrel %rel%{?gitdate:.%{gitdate}}
Summary:	OpenGL and ES 2.0 Benchmark
License:	GPLv3
URL:		https://github.com/glmark2/glmark2
Group:		Development/X11
# From https://github.com/glmark2/glmark2.git
# Use the included glmark2-getfromgit.sh script to generate the latest archive
Source0:	glmark2-%{ver}-%{gitdate}.git.%{githash}.tar.xz
Source1:	glmark2-getfromgit.sh
Source2:	glmark2-software
# fix loading order of GL libraries (versioned first)
Patch0:		glmark2-2020.04-change-so-names-order.patch
BuildRequires:	imagemagick
BuildRequires:	pkgconfig(egl)
BuildRequires:	pkgconfig(gbm)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glesv2)
BuildRequires:	pkgconfig(libdrm)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng12)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(udev)
BuildRequires:	pkgconfig(wayland-client)
BuildRequires:	pkgconfig(wayland-egl)
BuildRequires:	pkgconfig(wayland-protocols)
BuildRequires:	python3
BuildRequires:	waf
Recommends:	%{libglesv2name}

%description
Glmark2 is a benchmark for OpenGL 2.0 and ES 2.0.

%prep
%setup -q
%autopatch -p1

# Remove internal jpeg libraries
rm -rv src/libjpeg-turbo #src/libpng
%if %use_system_waf
rm -r waf waflib
%endif

%build
# Fix incorrect sRGB profile (from suse)
convert data/textures/effect-2d.png -strip data/textures/effect-2d.png
%if %use_system_waf
%waf \
	--with-flavors="drm-gl,drm-glesv2,x11-gl,x11-glesv2,wayland-gl,wayland-glesv2" \
	--prefix=%{_usr}
%waf_build
%else
export LINKFLAGS="${LINKFLAGS:-%build_ldflags}"
./waf configure \
	--with-flavors="drm-gl,drm-glesv2,x11-gl,x11-glesv2,wayland-gl,wayland-glesv2" \
	--prefix=%{_usr}
./waf build %_smp_mflags
%endif

%install
%if %use_system_waf
%waf_install
%else
./waf install --destdir=%{buildroot}
%endif

install -m 755 %{SOURCE2} %{buildroot}%{_bindir}

%files
# the x11 opengl benchmark
%doc NEWS README COPYING COPYING.SGI
%{_bindir}/%{name}
%{_bindir}/%{name}-drm
%{_bindir}/%{name}-es2
%{_bindir}/%{name}-es2-drm
%{_bindir}/%{name}-software
%{_bindir}/%{name}-wayland
%{_mandir}/man1/%{name}-wayland.1*
%{_bindir}/%{name}-es2-wayland
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/%{name}-drm.1*
%{_mandir}/man1/%{name}-es2.1*
%{_mandir}/man1/%{name}-es2-drm.1*
%{_mandir}/man1/%{name}-es2-wayland.1*
%{_datadir}/%{name}/


%changelog
* Sun Aug 02 2020 ghibo <ghibo> 2020.04-3.20200713.mga8
+ Revision: 1610634
- Update to release 20200713.

* Sat Jul 04 2020 ghibo <ghibo> 2020.04-3.20200503.mga8
+ Revision: 1601932
- Change loading order of GL libs to .so versioned first

* Fri Jun 12 2020 ghibo <ghibo> 2020.04-2.20200503.mga8
+ Revision: 1592865
- Rebuild against newer GL libs

* Fri May 08 2020 ghibo <ghibo> 2020.04-1.20200503.mga8
+ Revision: 1581823
- Update to release 2020.04.
- Don't use system's waf as it seems not compatible.

* Tue Feb 25 2020 daviddavid <daviddavid> 2017.07-6.20190327.mga8
+ Revision: 1550220
- use new waf macros

* Tue Feb 25 2020 daviddavid <daviddavid> 2017.07-5.20190327.mga8
+ Revision: 1550218
- use system waf
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Mon Apr 15 2019 ghibo <ghibo> 2017.07-4.20190327.mga7
+ Revision: 1391056
- Rebuilt against latest mesa rebuilt against llvm 8.0.0

* Fri Apr 12 2019 akien <akien> 2017.07-3.20190327.mga7
+ Revision: 1389364
- Git snapshot from 20190327 (still version 2017.07)

* Sun Sep 23 2018 umeabot <umeabot> 2017.07-2.20170908.mga7
+ Revision: 1297914
- Mageia 7 Mass Rebuild

* Sun Oct 22 2017 ghibo <ghibo> 2017.07-1.20170908.mga7
+ Revision: 1173033
- Add udev-devel to BuildRequires
- Update to release 2017.07 (20170728)+git

* Fri Mar 17 2017 ghibo <ghibo> 2014.03-1.20170210.mga6
+ Revision: 1093334
- Update to release git from 2017-02-20 (uses CLOCK_MONOTONIC instead of
  CLOCK_REALTIME, so it is not affected by ntp time drifts).

* Sun Nov 06 2016 ghibo <ghibo> 2014.03-1.20160914.mga6
+ Revision: 1065551
- Added imagemagick to BuildRequires
- imported package glmark2


* Sat Nov 05 2016 Giuseppe Ghibò - 2014.03-1.20160914.mga6
- Initial release.
